@@ -16,7 +16,8 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-namespace gda {
+namespace gda
+{
 	class Batch;
 	class Command;
 	class Connection;
@@ -27,17 +28,13 @@ namespace gda {
 	class Value;
 };
 
-extern "C" {
-#include "glib.h"
 #include "gda-client.h"
-
 #include "gda-batch.h"
 #include "gda-command.h"
 #include "gda-connection.h"
 #include "gda-error.h"
 #include "gda-field.h"
 #include "gda-recordset.h"
-}
 
 #include "gdaBatch.h"
 #include "gdaCommand.h"
