@@ -77,9 +77,7 @@ gda_field_get_type (void)
 static void
 gda_field_class_init (GdaFieldClass * klass)
 {
-	GtkObjectClass *object_class;
-
-	object_class = (GtkObjectClass *) klass;
+	GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
 }
 
 static void
@@ -226,7 +224,7 @@ gda_stringify_value (gchar * bfr, gint maxlen, GdaField * f)
 	if (bfr)
 		retval = bfr;
 
-	if (gda_field_isnull (f))
+	if (gda_field_is_null (f))
 		return g_strdup (_("<NULL>"));
 
 	switch (f->attributes->gdaType) {
@@ -239,15 +237,15 @@ gda_stringify_value (gchar * bfr, gint maxlen, GdaField * f)
 		break;
 	case GDA_TypeBigint:
 		if (!bfr) {
-			retval = g_new0 (gchar, 20);
+			retval = g_new (gchar, 20);
 			maxlen = 20;
 		}
-		g_snprintf (retval, maxlen, "%Ld", gda_field_bigint (f));
+		g_snprintf (retval, maxlen, "%Ld", gda_field_get_bigint_value (f));
 		break;
 	case GDA_TypeBoolean:
 		{
 			gchar *retstr;
-			if (gda_field_boolean (f))
+			if (gda_field_get_boolean_value (f))
 				retstr = _("TRUE");
 			else
 				retstr = _("FALSE");
@@ -281,15 +279,19 @@ gda_stringify_value (gchar * bfr, gint maxlen, GdaField * f)
 	case GDA_TypeLongvarchar:
 	case GDA_TypeVarchar:
 		if (!bfr) {
-			retval = g_strdup (f->real_value->_u.v._u.lvc);
+			if (f->real_value->_u.v._u.lvc != NULL)
+				retval = g_strdup (f->real_value->_u.v._u.lvc);
+			else
+				retval = g_strdup (_("<NULL>"));
 		}
 		else {
-			strncpy (retval, f->real_value->_u.v._u.lvc,
-				 min (maxlen,
-				      strlen (f->real_value->_u.v._u.lvc)));
-			retval[min
-			       (maxlen,
-				strlen (f->real_value->_u.v._u.lvc))] = '\0';
+			if (f->real_value->_u.v._u.lvc != NULL) {
+				strncpy (retval, f->real_value->_u.v._u.lvc,
+					 min (maxlen, strlen (f->real_value->_u.v._u.lvc)));
+				retval[min (maxlen, strlen (f->real_value->_u.v._u.lvc))] = '\0';
+			}
+			else
+				retval = g_strdup (_("<NULL>"));
 		}
 		break;
 	case GDA_TypeInteger:
@@ -408,7 +410,7 @@ gda_stringify_value (gchar * bfr, gint maxlen, GdaField * f)
 		}
 		g_print ("stringify for valuetype [%d]'%s' NYI\n",
 			 f->attributes->gdaType,
-			 gda_fieldtype_2_string (0, 20, gda_field_type (f)));
+			 gda_fieldtype_2_string (0, 20, gda_field_get_gdatype (f)));
 		retval[0] = '\0';
 		break;
 	}
@@ -438,7 +440,56 @@ void
 gda_field_free (GdaField * f)
 {
 	g_return_if_fail (GDA_IS_FIELD (f));
-	gtk_object_destroy (GTK_OBJECT (f));
+	gtk_object_unref (GTK_OBJECT (f));
+}
+
+/**
+ * gda_field_get_date_value
+ */
+GDate *
+gda_field_get_date_value (GdaField *field)
+{
+	GDate *dt = NULL;
+
+	g_return_val_if_fail (GDA_IS_FIELD (field), NULL);
+
+	if (field->attributes->gdaType == GDA_TypeDate) {
+		struct tm *stm;
+
+		stm = localtime ((time_t *) &field->real_value->_u.v._u.d);
+		if (stm != NULL) {
+			dt = g_date_new_dmy (stm->tm_mday,
+					     stm->tm_mon,
+					     stm->tm_year);
+		}
+	}
+	else if (field->attributes->gdaType == GDA_TypeDbDate) {
+		dt = g_date_new_dmy (field->real_value->_u.v._u.dbd.day,
+				     field->real_value->_u.v._u.dbd.month,
+				     field->real_value->_u.v._u.dbd.year);
+	}
+
+	return dt;
+}
+
+/**
+ * gda_field_get_timestamp_value
+ */
+time_t
+gda_field_get_timestamp_value (GdaField *field)
+{
+	struct tm stm;
+
+	g_return_val_if_fail (GDA_IS_FIELD (field), -1);
+
+	stm.tm_year = field->real_value->_u.v._u.dbtstamp.year;
+	stm.tm_mon = field->real_value->_u.v._u.dbtstamp.month;
+	stm.tm_mday = field->real_value->_u.v._u.dbtstamp.day;
+	stm.tm_hour = field->real_value->_u.v._u.dbtstamp.hour;
+	stm.tm_min = field->real_value->_u.v._u.dbtstamp.minute;
+	stm.tm_sec = field->real_value->_u.v._u.dbtstamp.second;
+
+	return mktime (&stm);
 }
 
 /**
@@ -455,10 +506,10 @@ gda_field_actual_size (GdaField * f)
 {
 	g_return_val_if_fail (GDA_IS_FIELD (f), 0);
 
-	if (gda_field_isnull (f))
+	if (gda_field_is_null (f))
 		return 0;
 
-	switch (gda_field_type (f)) {
+	switch (gda_field_get_gdatype (f)) {
 	case GDA_TypeTinyint:
 		return sizeof (CORBA_char);
 	case GDA_TypeBigint:
@@ -476,7 +527,7 @@ gda_field_actual_size (GdaField * f)
 	case GDA_TypeCurrency:
 	case GDA_TypeDecimal:
 	case GDA_TypeNumeric:
-		return strlen (gda_field_longvarchar (f));
+		return strlen (gda_field_get_string_value (f));
 	case GDA_TypeDouble:
 		return sizeof (CORBA_double);
 		/* case GDA_TypeError: NYI */
@@ -486,15 +537,15 @@ gda_field_actual_size (GdaField * f)
 	case GDA_TypeVarwchar:
 	case GDA_TypeLongvarwchar:
 	case GDA_TypeLongvarbin:
-		return gda_field_varbin_length (f);
+		return -1;
 	case GDA_TypeFixbin:
 	case GDA_TypeFixwchar:
 	case GDA_TypeFixchar:
-		return gda_field_fixbin_length (f);
+		return -1;
 	case GDA_TypeChar:
 	case GDA_TypeVarchar:
 	case GDA_TypeLongvarchar:
-		return strlen (gda_field_longvarchar (f));
+		return strlen (gda_field_get_string_value (f));
 	case GDA_TypeSingle:
 		return sizeof (CORBA_float);
 	case GDA_TypeSmallint:
@@ -507,6 +558,6 @@ gda_field_actual_size (GdaField * f)
 		break;
 	}
 	g_warning ("gda_field_actual_size: unknown GDA Type %d\n",
-		   gda_field_type (f));
+		   gda_field_get_gdatype (f));
 	return -1;
 }
