@@ -45,55 +45,50 @@ static gboolean log_enabled = TRUE;
 static gboolean
 save_log_cb (gpointer user_data)
 {
-  g_print(_("Saving log...x"));
-  gda_config_commit();
-  return TRUE;
+	g_print (_("Saving log...x"));
+	gda_config_commit ();
+	return TRUE;
 }
 
 static void
-write_to_log (const gchar *str, gboolean error)
+write_to_log (const gchar * str, gboolean error)
 {
-  gchar*          msg;
-  static gboolean initialized = FALSE;
+	gchar *msg;
+	static gboolean initialized = FALSE;
 
-  g_return_if_fail(str != NULL);
+	g_return_if_fail (str != NULL);
 
-  /* initialize log */
-  if (!initialized)
-    {
-      g_timeout_add (30000, (GSourceFunc) save_log_cb, NULL);
-      initialized = TRUE;
-    }
+	/* initialize log */
+	if (!initialized) {
+		g_timeout_add (30000, (GSourceFunc) save_log_cb, NULL);
+		initialized = TRUE;
+	}
 
-  /* compose message */
-  msg = g_strdup_printf("%s%s", error ? _("ERROR: ") : _("MESSAGE: "), str);
-  if (log_enabled)
-    {
-      time_t     t;
-      struct tm* now;
-      gchar*     config_entry;
+	/* compose message */
+	msg = g_strdup_printf ("%s%s", error ? _("ERROR: ") : _("MESSAGE: "),
+			       str);
+	if (log_enabled) {
+		time_t t;
+		struct tm *now;
+		gchar *config_entry;
 
-      /* retrieve current date */
-      t = time(NULL);
-      now = localtime(&t);
-      if (now)
-        {
-          config_entry = g_strdup_printf("%s/%s/%04d-%02d-%02d/%02d:%02d:%02d.%ld",
-                                         GDA_CONFIG_SECTION_LOG,
-                                         g_get_prgname(),
-                                         now->tm_year + 1900,
-                                         now->tm_mon + 1,
-                                         now->tm_mday,
-                                         now->tm_hour,
-                                         now->tm_min,
-                                         now->tm_sec,
-                                         clock());
-          gda_config_set_string(config_entry, msg);
-          g_free((gpointer) config_entry);
-        }
-    }
-  g_warning(msg);
-  g_free((gpointer) msg);
+		/* retrieve current date */
+		t = time (NULL);
+		now = localtime (&t);
+		if (now) {
+			config_entry =
+				g_strdup_printf
+				("%s/%s/%04d-%02d-%02d/%02d:%02d:%02d.%ld",
+				 GDA_CONFIG_SECTION_LOG, g_get_prgname (),
+				 now->tm_year + 1900, now->tm_mon + 1,
+				 now->tm_mday, now->tm_hour, now->tm_min,
+				 now->tm_sec, clock ());
+			gda_config_set_string (config_entry, msg);
+			g_free ((gpointer) config_entry);
+		}
+	}
+	g_warning (msg);
+	g_free ((gpointer) msg);
 }
 
 /**
@@ -104,7 +99,7 @@ write_to_log (const gchar *str, gboolean error)
 void
 gda_log_enable (void)
 {
-  log_enabled = TRUE;
+	log_enabled = TRUE;
 }
 
 /**
@@ -113,7 +108,7 @@ gda_log_enable (void)
 void
 gda_log_disable (void)
 {
-  log_enabled = FALSE;
+	log_enabled = FALSE;
 }
 
 /**
@@ -122,7 +117,7 @@ gda_log_disable (void)
 gboolean
 gda_log_is_enabled (void)
 {
-  return log_enabled;
+	return log_enabled;
 }
 
 /**
@@ -132,36 +127,36 @@ gda_log_is_enabled (void)
  * Logs the given message in the GDA log file
  */
 void
-gda_log_message (const gchar *format, ...)
+gda_log_message (const gchar * format, ...)
 {
-  va_list args;
-  gchar   buffer[512];
+	va_list args;
+	gchar buffer[512];
 
-  g_return_if_fail(format != NULL);
+	g_return_if_fail (format != NULL);
 
-  va_start(args, format);
-  vsprintf(buffer, format, args);
-  va_end(args);
+	va_start (args, format);
+	vsprintf (buffer, format, args);
+	va_end (args);
 
-  write_to_log(buffer, FALSE);
+	write_to_log (buffer, FALSE);
 }
 
 /**
  * gda_log_error
  */
 void
-gda_log_error (const gchar *format, ...)
+gda_log_error (const gchar * format, ...)
 {
-  va_list args;
-  gchar   buffer[512];
+	va_list args;
+	gchar buffer[512];
 
-  g_return_if_fail(format != NULL);
+	g_return_if_fail (format != NULL);
 
-  va_start(args, format);
-  vsprintf(buffer, format, args);
-  va_end(args);
+	va_start (args, format);
+	vsprintf (buffer, format, args);
+	va_end (args);
 
-  write_to_log(buffer, TRUE);
+	write_to_log (buffer, TRUE);
 }
 
 /**
@@ -171,6 +166,6 @@ gda_log_error (const gchar *format, ...)
  * Clear the entire log for the given program
  */
 void
-gda_log_clean_all (const gchar *prgname)
+gda_log_clean_all (const gchar * prgname)
 {
 }
